@@ -37,8 +37,8 @@ class MetalinkHttp : public AbstractMetalink
     // --- Job virtual functions ---
         void start();
         void stop();
-        void save(const QDomElement &element) { Q_UNUSED(element);}
-        void load(const QDomElement *element) { Q_UNUSED(element);}
+        void save(const QDomElement &element);
+        void load(const QDomElement *element);
         void deinit(Transfer::DeleteOptions options);
         void slotSignatureVerified();
 
